summaryrefslogtreecommitdiff
path: root/src/Cech_complex/include
diff options
context:
space:
mode:
Diffstat (limited to 'src/Cech_complex/include')
-rw-r--r--src/Cech_complex/include/gudhi/Miniball.COPYRIGHT (renamed from src/Cech_complex/include/Miniball/Miniball.COPYRIGHT)0
-rw-r--r--src/Cech_complex/include/gudhi/Miniball.README (renamed from src/Cech_complex/include/Miniball/Miniball.README)0
-rw-r--r--src/Cech_complex/include/gudhi/Miniball.hpp (renamed from src/Cech_complex/include/Miniball/Miniball.hpp)5
3 files changed, 4 insertions, 1 deletions
diff --git a/src/Cech_complex/include/Miniball/Miniball.COPYRIGHT b/src/Cech_complex/include/gudhi/Miniball.COPYRIGHT
index dbe4c553..dbe4c553 100644
--- a/src/Cech_complex/include/Miniball/Miniball.COPYRIGHT
+++ b/src/Cech_complex/include/gudhi/Miniball.COPYRIGHT
diff --git a/src/Cech_complex/include/Miniball/Miniball.README b/src/Cech_complex/include/gudhi/Miniball.README
index 86a96f08..86a96f08 100644
--- a/src/Cech_complex/include/Miniball/Miniball.README
+++ b/src/Cech_complex/include/gudhi/Miniball.README
diff --git a/src/Cech_complex/include/Miniball/Miniball.hpp b/src/Cech_complex/include/gudhi/Miniball.hpp
index a42d62a7..ce6cbb5b 100644
--- a/src/Cech_complex/include/Miniball/Miniball.hpp
+++ b/src/Cech_complex/include/gudhi/Miniball.hpp
@@ -32,6 +32,8 @@
#include <ctime>
#include <limits>
+namespace Gudhi {
+
namespace Miniball {
// Global Functions
@@ -514,7 +516,8 @@ namespace Miniball {
return -min_l;
return nt0;
}
+} // namespace Miniball
-} // end Namespace Miniball
+} // namespace Gudhi
#endif // MINIBALL_HPP_